/**
 * @copyright Copyright (c) 2020 Ivan Sein <ivan@nextcloud.com>
 *
 * @author Ivan Sein <ivan@nextcloud.com>
 *
 * @license GNU GPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#import "ChatTableViewCell.h"

@interface ChatTableViewCell () <UITextFieldDelegate>
@end

@implementation ChatTableViewCell

- (instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        _emojiTextField = [[EmojiTextField alloc] init];
        _emojiTextField.delegate = self;
        [self addSubview:_emojiTextField];
    }
    return self;
}

- (void)prepareForReuse
{
    [super prepareForReuse];
    self.messageId = -1;
    self.message = nil;
}

- (void)addReaction:(NSString *)reaction
{
    // Should be implemented in subclasses of ChatTableViewCell
}

#pragma mark - UITextField delegate

- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [_emojiTextField resignFirstResponder];
    return YES;
}

- (BOOL)textField:(UITextField *)textField shouldChangeCharactersInRange:(NSRange)range replacementString:(NSString *)string
{
    if (textField == _emojiTextField && string.isSingleEmoji) {
        [self addReaction:string];
    }
    [textField resignFirstResponder];
    return YES;
}

@end
